Improve this doc View Source

Configures the mock implementation of `$exceptionHandler` to rethrow or to log errors passed into the `$exceptionHandler`.

## Methods

- ###

  `mode(mode);`

  Sets the logging mode.

  #### Parameters

  Param | Type | Details
  --- | --- | ---
  - mode | string | Mode of operation, defaults to `rethrow`. `rethrow`: If any errors are passed into the handler in tests, it typically
               means that there is a bug in the application or test, so this mock will
               make these tests fail.
  - `log`: Sometimes it is desirable to test that an error is thrown, for this case the `log`
           mode stores an array of errors in `$exceptionHandler.errors`, to allow later
           assertion of them. See assertEmpty() and
           reset()